# -*- coding: utf-8 -*-
'''
Created on 22/giu/2011

@author: simone cittadini
'''

from django.db import models
from django_extensions.db.fields import AutoSlugField

from cms.models.fields import PlaceholderField
from jumbo.db.models import OrderedModel, UserModel, DateModel, StatusModel, HTMLField

from jcmsseo.models import SeoData


class AreaEventi(models.Model):
    """
    Un contenitore di eventi.
    """
    # Indica in quale posizione viene presentato all'iterno di una lista di
    #  aree evento.
    ordinale_pagina = models.PositiveIntegerField(unique=True)
    numero_eventi_mostrati = models.PositiveIntegerField()
    nome = models.CharField(max_length=64)
    slug = AutoSlugField('slug', populate_from='nome', overwrite=True)
    # Attenzione, il render di questi placeholder non è testo ma un paragrafo
    #  html. Quindi eventuali parametri del <p> vanno aggiunti editando da cms
    #  e non nel template della app.
    placeholder_titolo = PlaceholderField('placeholder_titolo', 
                                related_name='placeholder_titolo_areaeventi')
    placeholder_sottotitolo = PlaceholderField('placeholder_sottotitolo', 
                            related_name='placeholder_sottotitolo_areaeventi')
    
    def get_eventi(self):
        if Evento.objects.filter(area_evento__exact=self).count() > self.numero_eventi_mostrati:
            return Evento.objects.filter(area_evento__exact=self)[0:self.numero_eventi_mostrati]
        else:
            return Evento.objects.filter(area_evento__exact=self)

    
    def save(self, *args, **kwargs):
        # TODO auto slittare gli ordinali in caso di duplicato ?
        super(AreaEventi, self).save(*args, **kwargs)
        
    def __unicode__(self):
        return "%s - %s" % (self.ordinale_pagina, self.nome)
    
    class Meta:
        ordering = ('ordinale_pagina', 'nome')
        verbose_name_plural = ('AreeEventi')
    

class Evento(OrderedModel, UserModel, DateModel, StatusModel, SeoData):
    """
    Un evento.
    """
    nome = models.CharField(max_length=64)
    data_inizio = models.DateField(null=True, blank=True)
    data_fine = models.DateField(null=True, blank=True)
    orario_inizio = models.TimeField(null=True, blank=True)
    orario_fine = models.TimeField(null=True, blank=True)
    #TODO decidere struttura dir
    thumb = models.ImageField(upload_to="eventi")
    immagine = models.ImageField(upload_to="eventi")
    descrizione_riassuntiva = models.CharField(max_length=256)
    descrizione = HTMLField()
    link_esterno = models.URLField(null=True, blank=True)
    link_esterno_desc = models.CharField(max_length=128, null=True, blank=True)
    link_prenotazione = models.URLField(null=True, blank=True)
    link_prenotazione_desc = models.CharField(max_length=128, null=True,
                                              blank=True)
    
    area_evento = models.ForeignKey(AreaEventi, related_name="eventi_area")

    
    def __unicode__(self):
        return self.nome
    
    class Meta:
        ordering = ('ordering',)
        verbose_name_plural = ('Eventi')
