# -*- coding: utf-8 -*-
'''
Created on 21/giu/2011

@author: simone cittadini
'''
import string

from django.db import models
from cms.models.fields import PlaceholderField

from jumbo.db.models import UserModel, DateModel, StatusModel


class Glossario(models.Model):
    """
    Un contenitore di termini tecnici e relative descrizioni.
    Dato il tipo di CMS in cui verrà usata l'applicazione si dà per scontato
      in ogni sua funzione che il glossario sarà sempre solo uno.
    """
    nome = models.CharField(max_length=64)
    # Attenzione, il render di questi placeholder non è testo ma un paragrafo
    #  html. Quindi eventuali parametri del <p> vanno aggiunti editando da cms
    #  e non nel template della app.
    placeholder_titolo = PlaceholderField('placeholder_titolo', 
                                          related_name='placeholder_titolo')
    placeholder_sottotitolo = PlaceholderField('placeholder_sottotitolo', 
                                               related_name='placeholder_sottotitolo')
    placeholder_ricerca = PlaceholderField('placeholder_ricerca', 
                                           related_name='placeholder_ricerca')
    
    class Meta:
        ordering = ('nome',)
        verbose_name_plural = ('Glossario')
                
    def __unicode__(self):
        return self.nome

    @staticmethod
    def get_glossario():
        if Glossario.objects.all().count() > 0:
            return Glossario.objects.all()[0]
        else:
            return None
        
    @staticmethod
    def is_lettera_active(lettera):
        if Termine.objects.filter(nome__istartswith=lettera).count() > 0:
            return True
        else:
            return False
    
class Termine(UserModel, DateModel, StatusModel):
    nome = models.CharField(max_length=256, unique=True)
    descrizione = models.TextField()
    
    glossario = models.ForeignKey(Glossario, editable=False)
    
    
    def save(self, *args, **kwargs):
#        self.nome = string.capwords(self.nome.strip())
        self.glossario = Glossario.get_glossario()
        super(Termine, self).save(*args, **kwargs)
    
    def __unicode__(self):
        return self.nome
    
    class Meta:
        ordering = ('nome',)
        verbose_name_plural = ('Termini')
