# -*- coding: utf-8 -*-
'''
Created on 05/lug/2011

@author: simone cittadini
'''
from django import template
from django.template import resolve_variable, NodeList
from glossario.models import Glossario

register = template.Library()


@register.tag()
def ifletterused(parser, token):
    """
    Usage: {% ifletterused A %} ... {% endifletterused %}, or
           {% ifletterused A %} ... {% else %} ... {% endifletterused %}

    """
    try:
        tag, lettera = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError("Tag 'ifletterused' requires 1 argument.")
    
    nodelist_true = parser.parse(('else', 'endifletterused'))
    token = parser.next_token()
    
    if token.contents == 'else':
        nodelist_false = parser.parse(('endifletterused',))
        parser.delete_first_token()
    else:
        nodelist_false = NodeList()
    
    return ClassCheckNode(lettera, nodelist_true, nodelist_false)


class ClassCheckNode(template.Node):
    def __init__(self, lettera, nodelist_true, nodelist_false):
        self.lettera = lettera
        self.nodelist_true = nodelist_true
        self.nodelist_false = nodelist_false
    def render(self, context):
        #TODO così risolve la variabile "lettera" non il primo argomento
        l = resolve_variable('lettera', context)
            
        if Glossario.is_lettera_active(l):
            return self.nodelist_true.render(context)
        else:
            return self.nodelist_false.render(context)
