# -*- coding: utf-8 -*-
'''
Created on 19/lug/2011

@author: simone cittadini
'''
import datetime

from django.shortcuts import render_to_response
from django.conf import settings
from django.db.models.query_utils import Q

from news.models import News


def list_latest_news(num_news=None, category=None, sort='DESC',
                     last_months=None):
    kwargs = {}
    if category:
        kwargs.update({'categories__name__in': [category]})
    news = News.active.filter(**kwargs)

    q1 = Q(pub_date_begin__lte=datetime.datetime.now(),
           pub_date_end__gte=datetime.datetime.now())
    q2 = Q(event_date__lte=datetime.datetime.now())
    # simone cittadini, listo le news solo degli ultimi n mesi
    # (incluso il corrente), fa override di num_news
    if last_months:
        from_date = datetime.date(datetime.date.today().year,
                                  datetime.date.today().month -1,
                                  1)
        q3 = Q(event_date__gte=from_date)

    order_by = 'event_date'
    if sort == 'DESC':
        order_by = '-event_date'

    if last_months:
        qs = news.filter(q1 | q2).filter(q3).order_by(order_by)
    else:
        qs = news.filter(q1 | q2).order_by(order_by)

    if num_news:
        qs = qs[:num_news]

    return qs


class Gadget:

    def __init__(self):
        pass

    def gadget_info(self):
        fields = [
                {'title':'numero di notizie mostrate',
                 'id':'num_news',
                 'type':'text',
                 'value':'1'},
                {'title': 'categoria',
                 'id': 'category',
                 'type': 'text',
                 'value': 'news'},
                {'title': 'ordinamento',
                 'id': 'sort',
                 'type': 'choice',
                 'choices': [('DESC', 'Discendente'), ('ESC', 'Crescente')],
                 'value': 'Discendente'},
                 {'title': 'Ultimi mesi',
                  'id': 'last_months',
                  'type': 'text',
                  'value': '2'},
                  ]
        return {'name': 'gadget_last_news',
                'title': 'Le ultime notizie di AcomeA',
                'description': 'desc ultime notizie',
                'colour': 'color-green',
                'icon': '%sidashboard/img/circle.png' % settings.MEDIA_URL,
                'fields': fields}

    def view(self, request, dashboard_item):
        configurato = True
        try:
            options = dashboard_item.get_extra_fields()
            latest_news = list_latest_news(int(options['num_news']),
                                           options['category'],
                                           options['sort'],
                                           int(options['last_months']))
        except:
            configurato = False
        return render_to_response('idashboard/gadgets/gadget_last_news.html',
                                  locals())
