# -*- coding: utf-8 -*-
'''
Created on 24/giu/2011

@author: simone cittadini
'''
import os
import shlex
import subprocess

from django.core.files import File
from django.db import models
from django_extensions.db.fields import AutoSlugField

from cms.models.fields import PlaceholderField
from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jumbo.db.fields import HTMLField
from jcmsseo.models import SeoData


class AreaVideo(models.Model):
    """
    Un contenitore di video.
    """
    # Indica in quale posizione viene presentato all'iterno di una lista di
    #  aree video.
    ordinale_pagina = models.PositiveIntegerField(unique=True)
    numero_video_mostrati = models.PositiveIntegerField()
    nome = models.CharField(max_length=64)
    slug = AutoSlugField('slug', populate_from='nome', overwrite=True)
    # Attenzione, il render di questi placeholder non è testo ma un paragrafo
    #  html. Quindi eventuali parametri del <p> vanno aggiunti editando da cms
    #  e non nel template della app.
    placeholder_titolo = PlaceholderField('placeholder_titolo', 
                                          related_name='placeholder_titolo_areavideo')
    placeholder_sottotitolo = PlaceholderField('placeholder_sottotitolo', 
                                               related_name='placeholder_sottotitolo_areavideo')
    
    def get_video(self):
        if Video.objects.filter(area_video__exact=self).count() > self.numero_video_mostrati:
            return Video.objects.filter(area_video__exact=self)[0:self.numero_video_mostrati]
        else:
            return Video.objects.filter(area_video__exact=self)
        
    def __unicode__(self):
        return "%s - %s" % (self.ordinale_pagina, self.nome)
    
    class Meta:
        verbose_name_plural = ('AreeVideo')
    

class Video(OrderedModel, DateModel, UserModel, StatusModel, SeoData):
    """
    Un video. Nel template se il campo file è vuoto renderizzare il campo embed.
    """
    titolo = models.CharField(max_length=128)
    slug = AutoSlugField('slug', populate_from='titolo', overwrite=True)
    sottotitolo = models.CharField(max_length=256)
    descrizione = HTMLField()
    #TODO decidere struttura dir
    thumb = models.ImageField(upload_to="video", blank=True, null=True)
    file = models.FileField(upload_to="video", blank=True, null=True)
    likes = models.PositiveIntegerField(default=0)
    dislikes = models.PositiveIntegerField(default=0)
    visualizzazioni = models.PositiveIntegerField(default=0)
    embed_code = models.TextField(blank=True, null=True)
    autoencode = models.BooleanField(default=True)

    area_video = models.ForeignKey(AreaVideo, related_name="video_area")

    
    class Meta:
        ordering = ('ordering',)
        verbose_name_plural = ('Video')
        
    def __unicode__(self):
        return self.titolo
    
    def save(self, *args, **kwargs):
        # se è un nuovo video e non ho specificato un ordinale lo setto io
        # come +10 rispetto al più grande per quell'area.
        if self.pk == None and self.ordering == 0:
            try:
                qs_max_ordering = Video.objects.filter(
                        area_video__exact=self.area_video).order_by('-ordering')
                max_ordering = qs_max_ordering[0].ordering
                self.ordering = max_ordering + 10
            except:
                pass
            
        super(Video, self).save(*args, **kwargs)
        
        if self.file:
            if self.file.name.find('.flv') == -1 and self.autoencode:
                command_line = "ffmpeg -i %s -b 600k -r 30 -ab 128k -ar 44100 -s 390x294 -ac 2 -y /tmp/output.flv" % str(self.file.path)
                splitted_command_line = shlex.split(command_line)
                retcode = subprocess.call(splitted_command_line)
                temp_file = open("/tmp/output.flv")
                try:
                    filenamepre = self.file.name.split('.')[0]
                except:
                    filenamepre = self.file.name
                self.file.save("%s.flv" % filenamepre, File(temp_file))
                os.remove('/tmp/output.flv')
        

    def like(self):
        self.likes += 1
        self.save()
        
    def dislike(self):
        self.dislikes += 1
        self.save()
        
    def see(self):
        self.visualizzazioni += 1
        self.save()
